==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/VirtualDataSourceDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseDataSourceDescription } from "./BaseDataSourceDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let VirtualDataSourceDescription = /*@__PURE__*/ (() => {
    class VirtualDataSourceDescription extends BaseDataSourceDescription {
        constructor() {
            super();
            this.ax = false;
            this.ay = false;
            this.a4 = 0;
            this.a3 = 0;
            this.a2 = 0;
            this.a8 = null;
            this.aw = false;
        }
        get_type() {
            return "VirtualDataSource";
        }
        get isSectionCollapsable() {
            return this.ax;
        }
        set isSectionCollapsable(a) {
            this.ax = a;
            this.e("IsSectionCollapsable");
        }
        get isSectionExpandedDefault() {
            return this.ay;
        }
        set isSectionExpandedDefault(a) {
            this.ay = a;
            this.e("IsSectionExpandedDefault");
        }
        get pageSizeRequested() {
            return this.a4;
        }
        set pageSizeRequested(a) {
            this.a4 = a;
            this.e("PageSizeRequested");
        }
        get maxCachedPages() {
            return this.a3;
        }
        set maxCachedPages(a) {
            this.a3 = a;
            this.e("MaxCachedPages");
        }
        get actualPageSize() {
            return this.a2;
        }
        set actualPageSize(a) {
            this.a2 = a;
            this.e("ActualPageSize");
        }
        get concurrencyTag() {
            return this.a8;
        }
        set concurrencyTag(a) {
            this.a8 = a;
            this.e("ConcurrencyTag");
        }
        get isBatchingEnabled() {
            return this.aw;
        }
        set isBatchingEnabled(a) {
            this.aw = a;
            this.e("IsBatchingEnabled");
        }
    }
    VirtualDataSourceDescription.$t = /*@__PURE__*/ markType(VirtualDataSourceDescription, 'VirtualDataSourceDescription', BaseDataSourceDescription.$);
    return VirtualDataSourceDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/VirtualDataSourceDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseDataSourceDescription } from "./BaseDataSourceDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let VirtualDataSourceDescription = /*@__PURE__*/ (() => {
    class VirtualDataSourceDescription extends BaseDataSourceDescription {
        get_type() {
            return "VirtualDataSource";
        }
        constructor() {
            super();
            this.a5 = false;
            this.a6 = false;
            this.bc = 0;
            this.bb = 0;
            this.ba = 0;
            this.bg = null;
            this.a4 = false;
        }
        get isSectionCollapsable() {
            return this.a5;
        }
        set isSectionCollapsable(a) {
            this.a5 = a;
            this.g("IsSectionCollapsable");
        }
        get isSectionExpandedDefault() {
            return this.a6;
        }
        set isSectionExpandedDefault(a) {
            this.a6 = a;
            this.g("IsSectionExpandedDefault");
        }
        get pageSizeRequested() {
            return this.bc;
        }
        set pageSizeRequested(a) {
            this.bc = a;
            this.g("PageSizeRequested");
        }
        get maxCachedPages() {
            return this.bb;
        }
        set maxCachedPages(a) {
            this.bb = a;
            this.g("MaxCachedPages");
        }
        get actualPageSize() {
            return this.ba;
        }
        set actualPageSize(a) {
            this.ba = a;
            this.g("ActualPageSize");
        }
        get concurrencyTag() {
            return this.bg;
        }
        set concurrencyTag(a) {
            this.bg = a;
            this.g("ConcurrencyTag");
        }
        get isBatchingEnabled() {
            return this.a4;
        }
        set isBatchingEnabled(a) {
            this.a4 = a;
            this.g("IsBatchingEnabled");
        }
    }
    VirtualDataSourceDescription.$t = /*@__PURE__*/ markType(VirtualDataSourceDescription, 'VirtualDataSourceDescription', BaseDataSourceDescription.$);
    return VirtualDataSourceDescription;
})();
